FieldStrengthOrFluxDensity

Trait FieldStrengthOrFluxDensity 

pub trait FieldStrengthOrFluxDensity: Sealed {
    // Required method
    fn permeability(self, permeability: &FerromagneticPermeability) -> f64;
}
Sealed helper trait for FerromagneticPermeability::get.

This sealed trait is implemented for MagneticFieldStrength and MagneticFluxDensity to enable FerromagneticPermeability::get to receive either of the two quantities as arguments. It is not meant to be implemented for any other types or to be used on its own.

Required Methods

fn permeability(self, permeability: &FerromagneticPermeability) -> f64

Returns the relative permeability for self.

This function is used to implement FerromagneticPermeability::get and not meant to be used on its own.

Implementors

Source

impl FieldStrengthOrFluxDensity for Quantity<dyn Dimension<L = NInt<UInt<UTerm, B1>>, I = PInt<UInt<UTerm, B1>>, N = Z0, M = Z0, J = Z0, Th = Z0, Kind = dyn Kind, T = Z0>, dyn Units<f64, time = second, mass = kilogram, amount_of_substance = mole, electric_current = ampere, length = meter, luminous_intensity = candela, thermodynamic_temperature = kelvin>, f64>

Source

impl FieldStrengthOrFluxDensity for Quantity<dyn Dimension<L = Z0, I = NInt<UInt<UTerm, B1>>, N = Z0, M = PInt<UInt<UTerm, B1>>, J = Z0, Th = Z0, Kind = dyn Kind, T = NInt<UInt<UInt<UTerm, B1>, B0>>>, dyn Units<f64, time = second, mass = kilogram, amount_of_substance = mole, electric_current = ampere, length = meter, luminous_intensity = candela, thermodynamic_temperature = kelvin>, f64>