RectangularWire

Struct RectangularWire 

pub struct RectangularWire { /* private fields */ }
A rectangular bar made of a conducting material, usually a metal such as copper, possibly with an insulation layer.

This type of wire is often found in “constructed” windings such as hairpin windings with a low number of turns per coil. It is defined by the following fields:

  • height: Height of the bar. Must be positive.
  • width: Width of the bar. Must be positive.
  • insulation_thickness: Thickness of the insulation layer wrapped around the outer diameter. Must be positive or zero (zero means no insulation layer).
  • conductor_material: The material of the conductor.

The effective conductor area is the space between the inner and the outer diameter:

use std::sync::Arc;
use std::f64::consts::PI;

use approx::assert_abs_diff_eq;

use stem_wire::prelude::*;

let wire_round = RoundWire::new(
    Arc::new(Material::default()),
    Length::new::<millimeter>(2.0), // height
    Length::new::<millimeter>(1.0), // width
    Length::new::<millimeter>(0.1), // insulation_thickness
).expect("valid inputs");

assert_abs_diff_eq!(
    wire_round.effective_conductor_area(Area::new::<square_millimeter>(20.0), 3).get::<square_millimeter>(),
    PI - 0.25*PI,
    epsilon = 1e-3
);

Deserialization

All length fields accept SI units during deserialization (e.g. 8 mm, 0.5 m). See crate-level and dyn_quantity documentation for details.

Implementations

Source

impl RectangularWire

pub fn new( conductor_material: Arc<Material>, height: Length, width: Length, insulation_thickness: Length, ) -> Result<Self, Error>

Returns a new instance of RectangularWire if the given field values fulfill the following conditions:

  • height must be positive.
  • width must be positive.
  • insulation_thickness must be positive or zero.

See the struct docstring RectangularWire for more.

Examples
use std::sync::Arc;
use stem_wire::prelude::*;

assert!(RectangularWire::new(
    Arc::new(Material::default()),
    Length::new::<millimeter>(2.0),
    Length::new::<millimeter>(1.0),
    Length::new::<millimeter>(0.1)
).is_ok());

// Height is not positive
assert!(RectangularWire::new(
    Arc::new(Material::default()),
    Length::new::<millimeter>(0.0),
    Length::new::<millimeter>(1.0),
    Length::new::<millimeter>(0.1)
).is_err());

// Width is not positive
assert!(RectangularWire::new(
    Arc::new(Material::default()),
    Length::new::<millimeter>(2.0),
    Length::new::<millimeter>(-1.0),
    Length::new::<millimeter>(0.1)
).is_err());

// Insulation thickness is negative
assert!(RectangularWire::new(
    Arc::new(Material::default()),
    Length::new::<millimeter>(2.0),
    Length::new::<millimeter>(1.0),
    Length::new::<millimeter>(-0.1)
).is_err());
pub fn insulation_thickness(&self) -> Length

Returns the thickness of the insulation layer.

pub fn conductor_area(&self) -> Area

Returns the conductor area of the wire.

This function returns the same value as Wire::effective_conductor_area, but does not require zone_area and turns due to all needed information being stored within the RectangularWire struct.

Examples
use std::sync::Arc;
use stem_wire::prelude::*;

let wire = RectangularWire::new(
    Arc::new(Material::default()),
    Length::new::<millimeter>(2.0),
    Length::new::<millimeter>(1.0),
    Length::new::<millimeter>(0.1)
).expect("valid inputs");
assert_eq!(
    wire.conductor_area(),
    wire.effective_conductor_area(Default::default(), 0)
);
pub fn overall_area(&self) -> Area

Returns the overall area of the wire.

This function returns the same value as Wire::effective_overall_area, but does not require zone_area and turns due to all needed information being stored within the RectangularWire struct.

Examples
use std::sync::Arc;
use stem_wire::prelude::*;

let wire = RectangularWire::new(
    Arc::new(Material::default()),
    Length::new::<millimeter>(2.0),
    Length::new::<millimeter>(1.0),
    Length::new::<millimeter>(0.1)
).expect("valid inputs");
assert_eq!(
    wire.overall_area(),
    wire.effective_overall_area(Default::default(), 0)
);