Module round
stem_
wire
0.1.2
Module round
Module Items
Structs
In crate stem_
wire
stem_wire
Module
round
This module contains the predefined
Wire
type
RoundWire
.
Structs

Round
Wire
A flexible, round bar made of a conducting material, usually a metal such as copper, possibly with an insulation layer.