Module wire

Module wire 

The Wire trait for defining wires in stem.

A winding of an electrical machines creates a purposefully designed magnetic field when current passes through it. It is made up of individual wires (electric conductors) which are arranged in a certain geometric configuration which shapes the magnetic field. In stem, any type can be used as the wire of a winding if it implements the Wire trait. See its docstring for more.

Traits

Wire
A trait for defining wires for usage in windings.