pub struct CastWire(/* private fields */);Expand description
A cast “wire” filling an entire slot without insulation.
Casted “wires” are usually found in cage windings of asynchronous motors. They are created by filling liquid material into the slots of magnetic cores. Since the number of “turns” is always one for those kind of windings, the induced voltages are very low, meaning that typically no insulation is required. Hence, the wire fills the entire slot and is fully defined by its material. The slot fill factor is always 100%.
Examples
use std::sync::Arc;
use std::f64::consts::PI;
use approx::assert_abs_diff_eq;
use stem_wire::prelude::*;
let wire_round = CastWire::new(Arc::new(Material::default()));
assert_abs_diff_eq!(
wire_round.effective_conductor_area(Area::new::<square_millimeter>(20.0), 1).get::<square_millimeter>(),
20.0,
epsilon = 1e-3
);
assert_abs_diff_eq!(
wire_round.effective_conductor_area(Area::new::<square_millimeter>(50.0), 1).get::<square_millimeter>(),
50.0,
epsilon = 1e-3
);
// Giving a number of turns greater than 1 does not make any sense, but the
// function will return a sensible result anyway.
assert_abs_diff_eq!(
wire_round.effective_conductor_area(Area::new::<square_millimeter>(50.0), 2).get::<square_millimeter>(),
50.0,
epsilon = 1e-3
);
assert_eq!(wire_round.slot_fill_factor_conductor(Area::new::<square_millimeter>(20.0), 1), 1.0);
assert_eq!(wire_round.slot_fill_factor_overall(Area::new::<square_millimeter>(20.0), 1), 1.0);Implementations