pub fn serialize_quantity<S, T>(
value: &T,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>Expand description
Enables serialization of a quantity (any type implementing
Into<DynQuantity>) into a string containing both the value and the units.
When a value is serialized using serialize_with_units, this function stores
a quantity as a string containing both the raw value and the units.
If serialize_with_units is not used, this function serializes its field
using the default Serialize implementation of the type.
For examples see the serialize_with_units documentation.